@@ -14,16 +14,21 @@ from requests.auth import HTTPBasicAuth
 from requests_oauthlib import OAuth1, OAuth2
 
 from . import __version__
+from .advisory import TwythonDeprecationWarning
 from .compat import json, urlencode, parse_qsl, quote_plus, str, is_py2
 from .endpoints import EndpointsMixin
 from .exceptions import TwythonError, TwythonAuthError, TwythonRateLimitError
 from .helpers import _transparent_params
 
+import warnings
+
+warnings.simplefilter('always', TwythonDeprecationWarning)  # For Python 2.7 >
+
 
 class Twython(EndpointsMixin, object):
     def __init__(self, app_key=None, app_secret=None, oauth_token=None,
                  oauth_token_secret=None, access_token=None, token_type='bearer',
-                 oauth_version=1, api_version='1.1', client_args=None):
+                 oauth_version=1, api_version='1.1', client_args=None, auth_endpoint='authenticate'):
         """Instantiates an instance of Twython. Takes optional parameters for authentication and such (see below).
 
         :param app_key: (optional) Your applications key
@@ -38,6 +43,9 @@ class Twython(EndpointsMixin, object):
         :param client_args: (optional) Accepts some requests Session parameters and some requests Request parameters.
                             See http://docs.python-requests.org/en/latest/api/#sessionapi and requests section below it for details.
                             [ex. headers, proxies, verify(SSL verification)]
+        :param auth_endpoint: (optional) Lets you select which authentication endpoint will use your application.
+                              This will allow the application to have DM access if the endpoint is 'authorize'.
+                              Default: authenticate.
 
         """
 
@@ -54,7 +62,7 @@ class Twython(EndpointsMixin, object):
         # OAuth 1
         self.request_token_url = self.api_url % 'oauth/request_token'
         self.access_token_url = self.api_url % 'oauth/access_token'
-        self.authenticate_url = self.api_url % 'oauth/authenticate'
+        self.authenticate_url = self.api_url % ('oauth/%s' % auth_endpoint)
 
         if self.access_token:  # If they pass an access token, force OAuth 2
             oauth_version = 2
@@ -131,7 +139,10 @@ class Twython(EndpointsMixin, object):
                 'data': params,
                 'files': files,
             })
-        response = func(url, **requests_args)
+        try:
+            response = func(url, **requests_args)
+        except requests.RequestException as e:
+            raise TwythonError(str(e))
         content = response.content.decode('utf-8')
 
         # create stash for last function intel
@@ -166,13 +177,13 @@ class Twython(EndpointsMixin, object):
             if errors and isinstance(errors, list):
                 error_message = errors[0]['message']
             else:
-                error_message = errors
+                error_message = errors  # pragma: no cover
             self._last_call['api_error'] = error_message
 
             ExceptionType = TwythonError
             if response.status_code == 429:
                 # Twitter API 1.1, always return 429 when rate limit is exceeded
-                ExceptionType = TwythonRateLimitError
+                ExceptionType = TwythonRateLimitError  # pragma: no cover
             elif response.status_code == 401 or 'Bad Authentication data' in error_message:
                 # Twitter API 1.1, returns a 401 Unauthorized or
                 # a 400 "Bad Authentication data" for invalid/expired app keys/user tokens
@@ -183,7 +194,7 @@ class Twython(EndpointsMixin, object):
                                 retry_after=response.headers.get('retry-after'))
 
         # if we have a json error here, then it's not an official Twitter API error
-        if json_error and not response.status_code in (200, 201, 202):
+        if json_error and not response.status_code in (200, 201, 202):  # pragma: no cover
             raise TwythonError('Response was not valid JSON, unable to decode.')
 
         return content
@@ -245,7 +256,8 @@ class Twython(EndpointsMixin, object):
 
         :param callback_url: (optional) Url the user is returned to after they authorize your app (web clients only)
         :param force_login: (optional) Forces the user to enter their credentials to ensure the correct users account is authorized.
-        :param app_secret: (optional) If forced_login is set OR user is not currently logged in, Prefills the username input box of the OAuth login screen with the given value
+        :param screen_name: (optional) If forced_login is set OR user is not currently logged in, Prefills the username input box of the OAuth login screen with the given value
+
         :rtype: dict
         """
         if self.oauth_version != 1:
@@ -295,12 +307,26 @@ class Twython(EndpointsMixin, object):
         if self.oauth_version != 1:
             raise TwythonError('This method can only be called when your OAuth version is 1.0.')
 
-        response = self.client.get(self.access_token_url, params={'oauth_verifier': oauth_verifier})
+        response = self.client.get(self.access_token_url, params={'oauth_verifier': oauth_verifier}, headers={'Content-Type': 'application/json'})
+
+        if response.status_code == 401:
+            try:
+                try:
+                    # try to get json
+                    content = response.json()
+                except AttributeError:  # pragma: no cover
+                    # if unicode detected
+                    content = json.loads(response.content)
+            except ValueError:
+                content = {}
+
+            raise TwythonError(content.get('error', 'Invalid / expired Token'), error_code=response.status_code)
+
         authorized_tokens = dict(parse_qsl(response.content.decode('utf-8')))
         if not authorized_tokens:
             raise TwythonError('Unable to decode authorized tokens.')
 
-        return authorized_tokens
+        return authorized_tokens  # pragma: no cover
 
     def obtain_access_token(self):
         """Returns an OAuth 2 access token to make OAuth 2 authenticated read-only calls.
@@ -321,7 +347,7 @@ class Twython(EndpointsMixin, object):
             except AttributeError:
                 content = json.loads(content)
                 access_token = content['access_token']
-        except (ValueError, requests.exceptions.RequestException):
+        except (KeyError, ValueError, requests.exceptions.RequestException):
             raise TwythonAuthError('Unable to obtain OAuth 2 access token.')
         else:
             return access_token
@@ -354,13 +380,19 @@ class Twython(EndpointsMixin, object):
             )
         return '%s?%s' % (api_url, '&'.join(querystring))
 
-    def search_gen(self, search_query, **params):
-        """Returns a generator of tweets that match a specified query.
+    def search_gen(self, search_query, **params):  # pragma: no cover
+        warnings.warn(
+            'This method is deprecated. You should use Twython.cursor instead. [eg. Twython.cursor(Twython.search, q=\'your_query\')]',
+            TwythonDeprecationWarning,
+            stacklevel=2
+        )
+        return self.cursor(self.search, q=search_query, **params)
 
-        Documentation: https://dev.twitter.com/docs/api/1.1/get/search/tweets
+    def cursor(self, function, **params):
+        """Returns a generator for results that match a specified query.
 
-        :param search_query: Query you intend to search Twitter for
-        :param \*\*params: Extra parameters to send with your search request
+        :param function: Instance of a Twython function (Twython.get_home_timeline, Twython.search)
+        :param \*\*params: Extra parameters to send with your request (usually parameters excepted by the Twitter API endpoint)
         :rtype: generator
 
         Usage::
@@ -368,27 +400,46 @@ class Twython(EndpointsMixin, object):
           >>> from twython import Twython
           >>> twitter = Twython(APP_KEY, APP_SECRET, OAUTH_TOKEN, OAUTH_TOKEN_SECRET)
 
-          >>> search = twitter.search_gen('python')
-          >>> for result in search:
+          >>> results = twitter.cursor(twitter.search, q='python')
+          >>> for result in results:
           >>>   print result
 
         """
-        content = self.search(q=search_query, **params)
+        if not hasattr(function, 'iter_mode'):
+            raise TwythonError('Unable to create generator for Twython method "%s"' % function.__name__)
 
-        if not content.get('statuses'):
+        content = function(**params)
+
+        if not content:
             raise StopIteration
 
-        for tweet in content['statuses']:
-            yield tweet
+        if hasattr(function, 'iter_key'):
+            results = content.get(function.iter_key)
+        else:
+            results = content
+
+        for result in results:
+            yield result
+
+        if function.iter_mode == 'cursor' and content['next_cursor_str'] == '0':
+            raise StopIteration
 
         try:
-            if not 'since_id' in params:
-                params['since_id'] = (int(content['statuses'][0]['id_str']) + 1)
-        except (TypeError, ValueError):
+            if function.iter_mode == 'id':
+                if not 'max_id' in params:
+                    # Add 1 to the id because since_id and max_id are inclusive
+                    if hasattr(function, 'iter_metadata'):
+                        since_id = content[function.iter_metadata].get('since_id_str')
+                    else:
+                        since_id = content[0]['id_str']
+                    params['since_id'] = (int(since_id) - 1)
+            elif function.iter_mode == 'cursor':
+                params['cursor'] = content['next_cursor_str']
+        except (TypeError, ValueError):  # pragma: no cover
             raise TwythonError('Unable to generate next page of search results, `page` is not a number.')
 
-        for tweet in self.search_gen(search_query, **params):
-            yield tweet
+        for result in self.cursor(function, **params):
+            yield result
 
     @staticmethod
     def unicode2utf8(text):
@@ -404,3 +455,51 @@ class Twython(EndpointsMixin, object):
         if is_py2 and isinstance(text, (str)):
             return Twython.unicode2utf8(text)
         return str(text)
+
+    @staticmethod
+    def html_for_tweet(tweet, use_display_url=True, use_expanded_url=False):
+        """Return HTML for a tweet (urls, mentions, hashtags replaced with links)
+
+        :param tweet: Tweet object from received from Twitter API
+        :param use_display_url: Use display URL to represent link (ex. google.com, github.com). Default: True
+        :param use_expanded_url: Use expanded URL to represent link (e.g. http://google.com). Default False
+
+        If use_expanded_url is True, it overrides use_display_url.
+        If use_display_url and use_expanded_url is False, short url will be used (t.co/xxxxx)
+
+        """
+        if 'retweeted_status' in tweet:
+            tweet = tweet['retweeted_status']
+
+        if 'entities' in tweet:
+            text = tweet['text']
+            entities = tweet['entities']
+
+            # Mentions
+            for entity in entities['user_mentions']:
+                start, end = entity['indices'][0], entity['indices'][1]
+
+                mention_html = '<a href="https://twitter.com/%(screen_name)s" class="twython-mention">@%(screen_name)s</a>'
+                text = text.replace(tweet['text'][start:end], mention_html % {'screen_name': entity['screen_name']})
+
+            # Hashtags
+            for entity in entities['hashtags']:
+                start, end = entity['indices'][0], entity['indices'][1]
+
+                hashtag_html = '<a href="https://twitter.com/search?q=%%23%(hashtag)s" class="twython-hashtag">#%(hashtag)s</a>'
+                text = text.replace(tweet['text'][start:end], hashtag_html % {'hashtag': entity['text']})
+
+            # Urls
+            for entity in entities['urls']:
+                start, end = entity['indices'][0], entity['indices'][1]
+                if use_display_url and entity.get('display_url') and not use_expanded_url:
+                    shown_url = entity['display_url']
+                elif use_expanded_url and entity.get('expanded_url'):
+                    shown_url = entity['expanded_url']
+                else:
+                    shown_url = entity['url']
+
+                url_html = '<a href="%s" class="twython-url">%s</a>'
+                text = text.replace(tweet['text'][start:end], url_html % (entity['url'], shown_url))
+
+        return text
